@@ -60,6 +60,14 @@ int psgi_response(struct wsgi_request *wsgi_req, AV *response) {
 		return UWSGI_OK;
 	}
 
+	if (av_len(response) == -1) {
+		// deliberately empty response
+		wsgi_req->status = 101;
+		// don't actually close socket, it must be closed by application itself
+		wsgi_req->fd_closed = 1;
+		return UWSGI_OK;
+	}
+
 	status_code = av_fetch(response, 0, 0);
 	if (!status_code) { uwsgi_log("invalid PSGI status code\n"); return UWSGI_OK;}
 
