@@ -3,7 +3,7 @@ NAME='v8'
 
 CFLAGS = ['-Wno-deprecated-declarations']
 LDFLAGS = []
-LIBS = ['-lv8']
+LIBS = ['-lstdc++', '-lv8']
 engine = os.environ.get('UWSGICONFIG_V8_ENGINE', '')
 if engine == 'teajs':
     CFLAGS.append('-DUWSGI_V8_TEAJS -fexceptions')
